# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2011 Cubic ERP - Teradata SAC (<http://cubicerp.com>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
import netsvc
import datetime

class ir_translation(osv.osv):
    _name = 'ir.translation'
    _inherit = 'ir.translation'

#-------------------------------------------------------------
# Lithuanian
#-------------------------------------------------------------

    def lithuanian_number(self, val):
        to_19_lt = ( 'Nulis',  'Vienas',   'Du',  'Trys', 'Keturi',   'Penki',   'Šeši',
          'Septyni', 'Aštuoni', 'Devyni', 'Dešimt',   'Vienuolika', 'Dvylika', 'Trylika',
          'Keturiolika', 'Penkiolika', 'Šešiolika', 'Septyniolika', 'Aštuoniolika', 'Devyniolika' )
        tens_lt  = ( 'Dvidešimt', 'Tridešimt', 'Keturiasdešimt', 'Penkiasdešimt', 'Šešiasdešimt', 'Septyniasdešimt', 'Aštuoniasdešimt', 'Devyniasdešimt')
        denom_lt = ( '',
          'Tūkstantis',     'Milijonas',         'Milijardas',       'Trilijardas',       'Kvadrilijonas',
          'Kvintilijonas',  'Sextillion',      'Septilijonas',    'Oktilijonas',      'Nonilijonas',
          'Decilijonas',    'Undecillion',     'Duodecillion',  'Tredecillion',   'Quattuordecillion',
          'Sexdecillion', 'Septendecillion', 'Octodecillion', 'Novemdecillion', 'Vigintillion' )

        def _convert_nn_lt(val):
            """ 
            convert a value < 100 to Lithuanian
            """
            if val < 20:
                return to_19_lt[val]
            for (dcap, dval) in ((k, 20 + (10 * v)) for (v, k) in enumerate(tens_lt)):
                if dval + 10 > val:
                    if val % 10:
                        return dcap + ' ' + to_19_lt[val % 10]
                    return dcap

        def _convert_nnn_lt(val):
            """ convert a value < 1000 to Lithuanian
    
                special cased because it is the level that kicks 
                off the < 100 special case.  The rest are more general.  This also allows you to
                get strings in the form of 'forty-five hundred' if called directly.
            """
            word = ''
            (mod, rem) = (val % 100, val // 100)
            if rem > 1:
                word = to_19_lt[rem] + ' Šimtai'
                if mod > 0:
                    word += ' '
            else:
                word = 'Šimtas '
            if mod > 0:
                word += _convert_nn_lt(mod)
            return word


        if val < 100:
            return _convert_nn_lt(val)
        if val < 1000:
            return _convert_nnn_lt(val)
        for (didx, dval) in ((v - 1, 1000 ** v) for v in range(len(denom_lt))):
            if dval > val:
                mod = 1000 ** didx
                l = val // mod
                r = val - (l * mod)
                if val >= 2000:
                    if (l % 10 > 1 and l % 10 < 10 and l // 10 % 10 != 1):
                        if didx == 1:
                            denom_lt_new = denom_lt[didx][:-3] + 'čiai'
                        else:
                            denom_lt_new = denom_lt[didx][:-1] + 'i'
                    elif (l % 10 > 0 and l % 10 < 10 and l // 10 % 10 == 1):
                        if didx == 1:
                            denom_lt_new = denom_lt[didx][:-3] + 'čių'
                        else:
                            denom_lt_new = denom_lt[didx][:-2] + 'ų'
                    ret = _convert_nnn_lt(l) + ' ' + denom_lt_new
                else:        
                    ret = _convert_nnn_lt(l) + ' ' + denom_lt[didx]
                if r > 0:
                        ret = ret + ', ' + self.lithuanian_number(r)
                return ret

    def amount_to_text_lt(self, number, currency):
        number = '%.2f' % number
        units_name = currency
        if units_name == 'LTL' or units_name == 'EUR':
            number_float = float(number)
            if (number_float > 1 and (number_float // 10 % 10 != 1 and number_float % 10 != 0 and number_float % 10 != 1)):
                if units_name == 'LTL':
                    units_name = ' Litai'
                else:
                   units_name = ' Eurai'
            elif (number_float > 1 and number_float // 10 % 10 == 1 or number_float % 10 == 0):
                if units_name == 'LTL':
                   units_name = ' Litų'
                else:
                    units_name = ' Eurų'
            else:
                if units_name == 'LTL':
                    units_name = ' Litas'
                else:
                    units_name = ' Euras'
        list = str(number).split('.')
        start_word = self.lithuanian_number(abs(int(list[0])))
        end_word = self.lithuanian_number(int(list[1]))
        cents_number = int(list[1])
        if (cents_number > 1 and (cents_number // 10 % 10 != 1 and cents_number % 10 != 0)):
            cents_name = ' Centai'
        elif (cents_number > 1 and cents_number // 10 % 10 == 1 or cents_number % 10 == 0):
            cents_name = ' Centų'
        else:
            cents_name = ' Centas'
        final_result = start_word +' '+units_name+' '+ end_word +' '+cents_name
        return final_result

    _translate_funcs = {'co': 'self.amount_to_text_co', 'pe': 'self.amount_to_text_pe', 'es': 'self.amount_to_text_pe', 'en': 'self.amount_to_text_en', 'lt': 'self.amount_to_text_lt',}

ir_translation()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
